Learn R Programming

gtsf (version 0.1.0)

stops_for_routes: Get a set of stops for a set of routes

Description

Get a set of stops for a set of routes

Usage

stops_for_routes(g1, route_ids, select_service_ids, directional = FALSE)

Arguments

route_ids

the ids of the routes

directional

if the stops should by related to a route direction (e.g. inbound, outbound) - currently not implemented

a

dataframe output by join_mega_and_hf_routes()

service_id

the service for which to get stops

Value

stops for routes