Get a set of stops for a set of routes
stops_for_routes(g1, route_ids, select_service_ids, directional = FALSE)the ids of the routes
if the stops should by related to a route direction (e.g. inbound, outbound) - currently not implemented
dataframe output by join_mega_and_hf_routes()
the service for which to get stops
stops for routes